<?php 

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.


/* __________________________________________________________________________
 *
 * Scratch filter for Moodle 2.0
 *
 * This filter will replace any link to a Scratch file (.sb) 
 * with a java applet that plays that Scratch inline the Moodle page
 *
 * @package    filter
 * @subpackage scratch
 * @copyright  2011 Ralf Krause  {@link http://www.moodletreff.de}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 *
 * __________________________________________________________________________
 */


/* __________________________________________________________________________
 *
 * 
 * Scratch 1.4 License
 * 
 * Copyright (c) 2009 Massachusetts Institute of Technology
 * Scratch is developed by the Lifelong Kindergarten group at MIT Media Lab.
 * See http://scratch.mit.edu
 * 
 * The Scratch logo and the Scratch cat are trademarks of MIT.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining 
 * a copy of this software and accompanying documentation and media files 
 * (the "Software") to distribute the Software, including the right to use, 
 * copy, publish, or distribute copies of the Software, and to permit persons 
 * to whom the Software is furnished to do so, subject to the following 
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be included 
 * in all copies of the Software.
 * 
 * If the software is published or distributed, the following statement shall be 
 * displayed in a visible place on a website or on distribution media such as CDs:
 * 
 * Scratch is developed by the Lifelong Kindergarten group at the MIT Media Lab.
 * See http://scratch.mit.edu
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS 
 * IN THE SOFTWARE.
 *
 * __________________________________________________________________________
 */


defined('MOODLE_INTERNAL') || die();

require_once($CFG->libdir.'/filelib.php');

class filter_scratch extends moodle_text_filter {

    function filter($text, array $options = array()) {
        global $CFG, $PAGE;

        if (!is_string($text)) {
            // non string data can not be filtered anyway
            return $text;
        }

        $newtext = $text; // fullclone is slow and not needed here

        $search = '/<a.*?href="([^<]+\.sb)"[^>]*>.*?<\/a>/is';
        $newtext = preg_replace_callback($search, 'filter_scratch_callback', $newtext);

        if (is_null($newtext) or $newtext === $text) {
            // error or not filtered
            return $text;
        }

        return $newtext;
    }
}


function filter_scratch_callback($link) {
    global $CFG;

    $url = $link[1];
    $relative_url = str_replace($CFG->wwwroot . '/', '../../', $url);

    $path = explode("/", $link[1]);
    $filename = $path[count($path) - 1];

    $align = $CFG->filter_scratch_center? "margin: 0 auto 0 auto;" : (get_string('thisdirection', 'langconfig') == 'ltr'? "margin: 0 auto 0 0;" : "margin: 0 0 0 auto;");
    $autostart = $CFG->filter_scratch_autostart? 'true' : 'false';
    $copyright = '<br /><span style="font-size: 9px;">Scratch is developed by the Lifelong Kindergarten Group at the MIT Media Lab. See <a href="http://scratch.mit.edu" target="_blank">http://scratch.mit.edu</a></span>';
    $download = $CFG->filter_scratch_download? '<br /><a href="' . $url .'"><img style="width:16px; height:16px;" src="' . $CFG->wwwroot . '/filter/scratch/download.gif" /> ' . $filename . '</a>' : '';

    $html  = '<div style="width: 100%;">';
    $html .= '<div style="width: 482px; text-align: center; padding:4px 0px; ' . $align . '">';
    $html .= '<object type="application/x-java-applet" align="center" width="482" height="387">';
    $html .= '<param name="codebase" value="' . $CFG->wwwroot . '/filter/scratch/">';
    $html .= '<param name="code" value="ScratchApplet">';
    $html .= '<param name="archive" value="ScratchApplet.jar">';
    $html .= '<param name="project" value="' . $relative_url . '">';
    $html .= '<param name="autostart" value="' . $autostart . '">';
    $html .= '<h3><a href="http://www.java.com/getjava/">Install Java</a> to view this project right on your browser!</h3>';
    $html .= '</object>';
    $html .= $copyright;
    $html .= $download;
    $html .= '</div>';
    $html .= '</div>';

    return $html;
}

?>
